
from pyspedas.themis.spacecraft.fields.fgm import fgm
from pyspedas.themis.spacecraft.fields.fit import fit
from pyspedas.themis.spacecraft.fields.efi import efi
from pyspedas.themis.spacecraft.fields.fft import fft
from pyspedas.themis.spacecraft.fields.fbk import fbk
from pyspedas.themis.spacecraft.fields.scm import scm

from pyspedas.themis.spacecraft.particles.esa import esa
from pyspedas.themis.spacecraft.particles.sst import sst
from pyspedas.themis.spacecraft.particles.mom import mom
from pyspedas.themis.spacecraft.particles.gmom import gmom

from pyspedas.themis.ground.gmag import gmag
from pyspedas.themis.ground.ask import ask

from pyspedas.themis.state.state import state
from pyspedas.themis.state.slp import slp

from pyspedas.themis.state.autoload_support import autoload_support
from pyspedas.themis.state import get_spinmodel
from pyspedas.themis.cotrans import sse2sel,gse2sse,dsl2gse,ssl2dsl


import os
import unittest
from pytplot import data_exists
import pyspedas


class LoadTestCases(unittest.TestCase):
    def test_load_mag_data(self):
        mag_vars = pyspedas.dscovr.mag(time_clip=True)
        self.assertTrue(data_exists('dsc_h0_mag_B1RTN'))
        self.assertTrue(data_exists('dsc_h0_mag_B1GSE'))
        mag_vars = pyspedas.dscovr.mag(notplot=True)
        self.assertTrue('dsc_h0_mag_B1GSE' in mag_vars)

    def test_load_fc_data(self):
        fc_vars = pyspedas.dscovr.fc()
        self.assertTrue(data_exists('dsc_h1_fc_Np'))
        self.assertTrue(data_exists('dsc_h1_fc_THERMAL_TEMP'))

    def test_load_orb_data(self):
        orb_vars = pyspedas.dscovr.orb()
        self.assertTrue(data_exists('dsc_orbit_GSE_POS'))
        self.assertTrue(data_exists('dsc_orbit_GCI_POS'))

    def test_load_att_data(self):
        att_vars = pyspedas.dscovr.att()
        self.assertTrue(data_exists('dsc_att_GCI_Yaw'))
        self.assertTrue(data_exists('dsc_att_GCI_Pitch'))
        self.assertTrue(data_exists('dsc_att_GCI_Roll'))

    def test_load_downloadonly(self):
        files = pyspedas.dscovr.mag(downloadonly=True, trange=['2018-12-15', '2018-12-16'])
        self.assertTrue(os.path.exists(files[0]))

    def test_load_all(self):
        t_all = pyspedas.dscovr.all()
        self.assertTrue(len(t_all) > 0)
        
        
if __name__ == '__main__':
    unittest.main()
